function test_teig,
# g(x) = 8 - 10 * cos(x) + 2 cos(2 * x)
# coefs are the first entries of the first column of the banded Toeplitz matrix
coefs = [8; -5; 1];
n = 900;
A = symmetricbandtoeplitz(coefs, n);

fprintf('\nTest the eigenvalues for n = %d.\n', n);
tic; e1 = eig(A); t1 = toc;
fprintf('Time = %.3f with the general algorithm.\n', t1);
tic; e2 = teig(coefs, n); t2 = toc;
fprintf('Time = %.3f with our algorithm.\n', t2);
fprintf('Maximum error of the eigenvalues: %.2e\n\n', norm(e1 - e2, 'inf'));

fprintf('Test the eigenvectors for n = %d.\n', n);
tic; [e3, P] = eig(A); t3 = toc;
fprintf('Time = %.3f with general algorithm.\n', t3);
tic; [e4, Q] = teig(coefs, n); t4 = toc;
fprintf('Time = %.3f with our algorithm.\n', t4);
er1 = norm(Q' * Q - eye(n));
er2 = norm(A * Q - Q * diag(e4));
fprintf('Error of orthonormality = %.2e\n', er1);
fprintf('norm(A * Eigvecs - Eigvecs * diag(eigvals)) = %.2e.\n\n', er2);
end

function A = symmetricbandtoeplitz(coefs, n),
  k = min(length(coefs), n);
  fullcoefs = [coefs(1 : k); zeros(n - k, 1)];
  A = toeplitz(fullcoefs);
end

